from setuptools import setup, find_packages

setup(
    name='nlgmal',
    version='0.1.4',
    packages=find_packages(),
    description='A custom cryptographic package using the NLGdecimal number system.',
    author='NLG SAKIB',
    author_email='nlgarts@outlook.com',
    license='MIT',
    install_requires=[],
)
